==> service_client-0.0.4-20211014.015544-7-sources.jar: com/northpool/service/manager/texture/TextureManager.java <==
package com.northpool.service.manager.texture;

import com.alibaba.fastjson.JSON;
import com.northpool.resources.command.Constants;
import com.northpool.resources.command.QueryFilter;
import com.northpool.resources.exception.IdFieldValueEmptyException;
import com.northpool.service.config.texture.ITextureService;
import com.northpool.service.config.texture.TextureBean;
import com.northpool.service.config.texture.TextureBuilder;
import com.northpool.service.dao.texture.TextureMongoDao;
import com.northpool.service.dao.texture.TextureZkDao;
import com.northpool.service.manager.abstractclass.*;
import org.apache.commons.lang3.StringUtils;

import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

public class TextureManager  extends AbstractManager<ITextureService, TextureBuilder> implements ITextureManager {

    protected static final String MANAGER_ROOT = "texture";

    protected static final String MONGO_COLLECTION_NAME = "TAB_MAPENGINE_TEXTURE_INFO";

    protected static final String idField = "id";

    public TextureManager(){
        super(idField, TextureBuilder.getInstance(), MANAGER_ROOT);

    }

    public void init(){
        super.init();
        this.mongoDao = new TextureMongoDao(client.initMongoClient(),  MONGO_COLLECTION_NAME, "id", beanBuilder);
        if (client.getZoo() != null) {
            this.zkDao = new TextureZkDao(idFieldName, beanBuilder, table, client, managerRoot, readOnly);
            this.zkDao.init();
            try {
                this.zkDao.syncFromZK();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @Override
    public void add(List<ITextureService> textures) throws ExistsIdException, IdFieldValueEmptyException, ZKException, NotReadyException, TextureInValidException {
        ITextureService texture = null;
        Set<String> inValidNames = new HashSet<>();
        for (int i = 0; i < textures.size(); i++) {
            texture = textures.get(i);
            if (!texture.isValid()){
                inValidNames.add(texture.getName());
            }
        }
        if (!inValidNames.isEmpty()){//检查不符合要求的符号，批量抛出异常
            String names = StringUtils.join(inValidNames, ",");
            //throw new TextureInValidException("符号 " + names + " 不符合要求！");
        }

        for (int i = 0; i < textures.size(); i++) {
            texture = textures.get(i);
            super.doAdd(textures.get(i));
        }
    }

    @Override
    public void remove(String[] ids) throws NotReadyException, NotFoundException, ZKException {
        for (int i = 0; i < ids.length; i++) {
            super.doRemove(ids[i]);
        }
    }

    @Override
    public String list(String ids) throws Exception {
        if(StringUtils.isEmpty(ids)){
            return "[]";
        }
        QueryFilter filter = new QueryFilter();
        filter.addFilter(idField, Constants.OPERATION.IN, ids.split(","));
        List<ITextureService> texturesList = this.list(filter);
        List<TextureBean> textureBeans = texturesList.stream().map(texture -> texture.getBean()).collect(Collectors.toList());
        return JSON.toJSONString(textureBeans);
    }


}

==> service_client-0.0.4-20211224.070125-23-sources.jar: com/northpool/service/manager/texture/TextureManager.java <==
package com.northpool.service.manager.texture;

import com.alibaba.fastjson.JSON;
import com.northpool.resources.command.Constants;
import com.northpool.resources.command.QueryFilter;
import com.northpool.service.config.texture.ITextureService;
import com.northpool.service.config.texture.TextureBean;
import com.northpool.service.config.texture.TextureBuilder;
import com.northpool.service.dao.texture.TextureMongoDao;
import com.northpool.service.dao.texture.TextureZkDao;
import com.northpool.service.manager.abstractclass.*;
import org.apache.commons.lang3.StringUtils;

import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

public class TextureManager  extends AbstractManager<ITextureService, TextureBuilder> implements ITextureManager {

    protected static final String MANAGER_ROOT = "texture";

    protected static final String MONGO_COLLECTION_NAME = "TAB_MAPENGINE_TEXTURE_INFO";

    protected static final String idField = "id";

    public TextureManager(){
        super(idField, TextureBuilder.getInstance(), MANAGER_ROOT);

    }

    public void init(){
        super.init();
        this.mongoDao = new TextureMongoDao(client.initMongoClient(),  MONGO_COLLECTION_NAME, "id", beanBuilder);
        if (client.getZoo() != null) {
            this.zkDao = new TextureZkDao(idFieldName, beanBuilder, table, client, managerRoot, readOnly);
            this.zkDao.init();
            try {
                this.zkDao.syncFromZK();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @Override
    public void add(List<ITextureService> textures) throws ZKException {
        ITextureService texture = null;
        Set<String> inValidNames = new HashSet<>();
        for (int i = 0; i < textures.size(); i++) {
            texture = textures.get(i);
            if (!texture.isValid()){
                inValidNames.add(texture.getName());
            }
        }
        if (!inValidNames.isEmpty()){//检查不符合要求的符号，批量抛出异常
            String names = StringUtils.join(inValidNames, ",");
            //throw new TextureInValidException("符号 " + names + " 不符合要求！");
        }

        for (int i = 0; i < textures.size(); i++) {
            texture = textures.get(i);
            super.doAdd(textures.get(i));
        }
    }

    @Override
    public void remove(String[] ids) throws ZKException {
        for (int i = 0; i < ids.length; i++) {
            super.doRemove(ids[i]);
        }
    }

    @Override
    public String list(String ids)  {
        if(StringUtils.isEmpty(ids)){
            return "[]";
        }
        QueryFilter filter = new QueryFilter();
        filter.addFilter(idField, Constants.OPERATION.IN, ids.split(","));
        List<ITextureService> texturesList = this.list(filter);
        List<TextureBean> textureBeans = texturesList.stream().map(texture -> texture.getBean()).collect(Collectors.toList());
        return JSON.toJSONString(textureBeans);
    }


}
